local mod = ...




-- Assignable function list
function AppendSecurityFunction(listId, func)

    mod:override({
        Id = listId,
        AssetFunctionList = {
            Action = "APPEND",
            func,
        }
    })

end



-- Security generator
function AttachSecurityGenerator(prefab, base, worker)

    mod:registerPrefabComponent(prefab, {
        DataType = "COMP_SECURITY_POINTS",
        BasePoints = base,
        WorkerPoints = worker
    })

    mod:registerPrefabComponent(prefab, {
        DataType = "COMP_SECURITY_OVERLAY"
    })

end



-- Frontier Fortifications mod -------------------------------------------------------------------------------------
if (foundation.isModLoaded("7c53a142-5dc3-4947-aa65-37d591ca927c")) then

    mod:override({
        Id = "BUILDING_PART_FRONTIER_KEEP1",
        AssetBuildingFunction = "BUILDING_FUNCTION_SECURITY_CONSTABLE"
    })

    mod:override({
        Id = "BUILDING_PART_FRONTIER_TOWER1",
        AssetBuildingFunction = "BUILDING_FUNCTION_SECURITY_GUARD1"
    })

    mod:override({
        Id = "BUILDING_PART_FRONTIER_TOWER2",
        AssetBuildingFunction = "BUILDING_FUNCTION_SECURITY_GUARD1"
    })

    mod:override({
        Id = "BUILDING_PART_FRONTIER_GATE1",
        AssetBuildingFunction = "BUILDING_FUNCTION_SECURITY_GUARD1"
    })

    mod:override({
        Id = "BUILDING_PART_FRONTIER_GATE4",
        AssetBuildingFunction = "BUILDING_FUNCTION_SECURITY_GUARD1"
    })

    mod:registerPrefabComponent("PREFAB_FRONTIER_KEEP1", { DataType = "COMP_SECURITY_POINTS", BasePoints = 4, WorkerPoints = 2 } )
    mod:registerPrefabComponent("PREFAB_FRONTIER_TOWER1", { DataType = "COMP_SECURITY_POINTS", BasePoints = 2, WorkerPoints = 2 } )
    mod:registerPrefabComponent("PREFAB_FRONTIER_TOWER2", { DataType = "COMP_SECURITY_POINTS", BasePoints = 2, WorkerPoints = 2 } )
    mod:registerPrefabComponent("PREFAB_FRONTIER_GATE1", { DataType = "COMP_SECURITY_POINTS", BasePoints = 2, WorkerPoints = 2 } )
    mod:registerPrefabComponent("PREFAB_FRONTIER_GATE4", { DataType = "COMP_SECURITY_POINTS", BasePoints = 2, WorkerPoints = 2 } )

    mod:registerPrefabComponent("PREFAB_FRONTIER_KEEP1", { DataType = "COMP_SECURITY_OVERLAY" } )
    mod:registerPrefabComponent("PREFAB_FRONTIER_TOWER1", { DataType = "COMP_SECURITY_OVERLAY" } )
    mod:registerPrefabComponent("PREFAB_FRONTIER_TOWER2", { DataType = "COMP_SECURITY_OVERLAY" } )
    mod:registerPrefabComponent("PREFAB_FRONTIER_GATE1", { DataType = "COMP_SECURITY_OVERLAY" } )
    mod:registerPrefabComponent("PREFAB_FRONTIER_GATE4", { DataType = "COMP_SECURITY_OVERLAY" } )

    mod:override({
        Id = "BUILDING_FRONTIER",
        BuildingPartSetList = {
            Action = "APPEND",
            {
                Name = "BUILDING_SECURITY_NAME",
                BuildingPartList = {
                    "BUILDING_PART_SECURITY_PATROLPOINT",
                },
            },
        },
    })



end



-- Wooden Keep
-- note: adding the security points is dealt with in the component script
AppendSecurityFunction("BUILDING_FUNCTION_LIST_KEEP", "BUILDING_FUNCTION_SECURITY_GUARD2")

mod:override({
    Id = "MONUMENT_WOODEN_KEEP",
    BuildingPartSetList = {
        Action = "APPEND",
        {
            Name = "BUILDING_PART_SETLIST_SECURITY_NAME",
            BuildingPartList = {
                "BUILDING_PART_SECURITY_PATROLPOINT",
            },
        },
    },
})



-- Lord Manor
-- note: adding the security points is dealt with in the component script
AppendSecurityFunction("BUILDING_FUNCTION_LIST_LORD_MANOR", "BUILDING_FUNCTION_SECURITY_GUARD2")

mod:override({
    Id = "MONUMENT_RUSTIC_LORD_MANOR",
    BuildingPartSetList = {
        Action = "APPEND",
        {
            Name = "BUILDING_PART_SETLIST_SECURITY_NAME",
            BuildingPartList = {
                "BUILDING_PART_SECURITY_PATROLPOINT",
            },
        },
    },
})



-- Giant Gate masterpiece
-- note: adding the security points is dealt with in the component script
mod:override({
    Id = "BUILDING_PART_GATE_ROUND_TOWER",
    AssetBuildingFunction = "BUILDING_FUNCTION_SECURITY_GUARD2"
})

mod:override({
    Id = "BUILDING_PART_GATE_ROUND_WATCHTOWER",
    AssetBuildingFunction = "BUILDING_FUNCTION_SECURITY_GUARD2"
})

mod:override({
    Id = "BUILDING_PART_GATE_TOWER",
    AssetBuildingFunction = "BUILDING_FUNCTION_SECURITY_GUARD2"
})

mod:override({
    Id = "BUILDING_PART_GATE_WATCHTOWER",
    AssetBuildingFunction = "BUILDING_FUNCTION_SECURITY_GUARD2"
})

-- does not exist anymore?
-- mod:override({
--     Id = "MONUMENT_WATCH_TOWER",
--     BuildingPartSetList = {
--         Action = "APPEND",
--         {
--             Name = "BUILDING_PART_SETLIST_SECURITY_NAME",
--             BuildingPartList = {
--                 "BUILDING_PART_SECURITY_PATROLPOINT",
--             },
--         },
--     },
-- })



-- Stone Gate Set V7
if (foundation.isModLoaded("ad4b77eb-f903-4ade-89df-043293e696ec")) then

    -- Add patrol point for guards to use
    mod:override({
        Id = "STONE_GATE_V7_MONUMENT",
        BuildingPartSetList = {
            Action = "APPEND",
            {
                Name = "BUILDING_PART_SETLIST_SECURITY_NAME",
                BuildingPartList = {
                    "BUILDING_PART_SECURITY_PATROLPOINT",
                },
            },
        },
    })

    -- Append constable and guard functions to appropriate function lists

    AppendSecurityFunction("STONE_GATE_V7_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    -- AppendSecurityFunction("STONE_GATE_V7__MAIN_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_KEEPL_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_KEEPJ_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_KEEP_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_CIRCULAR_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_CIRCULAR_ROOTB_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    -- AppendSecurityFunction("STONE_GATE_V7__MAIN_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_MAIN_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_OTOWER_ROOTB_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_KEEPK_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_KEEP_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    -- AppendSecurityFunction("STONE_GATE_V7__MAIN_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_MAIN_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_MAIN_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_KEEP_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_OTOWER_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_OTOWER_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_CIRCULAR_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_KEEPH_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")
    AppendSecurityFunction("STONE_GATE_V7_KEEPI_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_CONSTABLE")

    AppendSecurityFunction("STONE_GATE_V7_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    -- AppendSecurityFunction("STONE_GATE_V7__MAIN_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_KEEPL_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_KEEPJ_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_KEEP_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_CIRCULAR_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_CIRCULAR_ROOTB_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    -- AppendSecurityFunction("STONE_GATE_V7__MAIN_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_MAIN_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_OTOWER_ROOTB_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_KEEPK_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_KEEP_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    -- AppendSecurityFunction("STONE_GATE_V7__MAIN_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_MAIN_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_MAIN_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_KEEP_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_OTOWER_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_OTOWER_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_CIRCULAR_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_KEEPH_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")
    AppendSecurityFunction("STONE_GATE_V7_KEEPI_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_PRISON")

    AppendSecurityFunction("STONE_GATE_V7_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    -- AppendSecurityFunction("STONE_GATE_V7__MAIN_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_KEEPL_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_SCT_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_SST_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_KEEPJ_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_KEEP_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_CIRCULAR_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_EMPTY_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_CIRCULAR_ROOTB_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    -- AppendSecurityFunction("STONE_GATE_V7__MAIN_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_MAIN_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_OTOWER_ROOTB_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_KEEPK_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_KEEP_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    -- AppendSecurityFunction("STONE_GATE_V7__MAIN_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_MAIN_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_MAIN_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_KEEP_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_SST_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_SST_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_OTOWER_ROOT_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_OTOWER_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_CIRCULAR_ROOTHALFWHITE_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_SCT_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_KEEPH_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")
    AppendSecurityFunction("STONE_GATE_V7_KEEPI_ROOTP_FUNCTION_LIST", "BUILDING_FUNCTION_SECURITY_GUARD2")

    -- Attach security generator to prefabs
    AttachSecurityGenerator("STONE_GATE_V7_CIRCULAR_TOP_PREFAB", 8, 2)
    AttachSecurityGenerator("STONE_GATE_V7_KEEP_TOP_PREFAB", 8, 2)
    AttachSecurityGenerator("STONE_GATE_V7_KEEPH_TOP_PREFAB", 8, 2)
    AttachSecurityGenerator("STONE_GATE_V7_KEEPI_TOP_PREFAB", 8, 2)
    AttachSecurityGenerator("STONE_GATE_V7_KEEPJ_TOP_PREFAB", 8, 2)
    AttachSecurityGenerator("STONE_GATE_V7_KEEPK_TOP_PREFAB", 8, 2)
    AttachSecurityGenerator("STONE_GATE_V7_KEEPL_TOP_PREFAB", 8, 2)
    AttachSecurityGenerator("STONE_GATE_V7_MAIN_TOP_PREFAB", 8, 2)
    AttachSecurityGenerator("STONE_GATE_V7_OTOWER_TOP_PREFAB", 8, 2)
    AttachSecurityGenerator("STONE_GATE_V7_SCT_TOP_PREFAB", 4, 2)
    AttachSecurityGenerator("STONE_GATE_V7_SGATE_TOP_A_PREFAB", 4, 2)
    AttachSecurityGenerator("STONE_GATE_V7_SGATE_TOP_PREFAB", 4, 2)
    AttachSecurityGenerator("STONE_GATE_V7_SST_TOP_PREFAB", 4, 2)

end